package com.usky.dxtop.controller.web;


import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.AjaxResult;
import com.usky.dxtop.common.core.page.TableDataInfo;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.QRCodeUtil;
import com.usky.dxtop.common.utils.SecurityUtils;
import com.usky.dxtop.common.utils.file.FileUtils;
import com.usky.dxtop.common.utils.spring.GlobalUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.QrCode;
import com.usky.dxtop.model.TopRadio;
import com.usky.dxtop.service.QrCodeService;
import com.usky.dxtop.service.TopRadioService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.net.ConnectException;
import java.util.List;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/qrCode")
public class QrCodeController extends BaseController {


    @Autowired
    private QrCodeService qrCodeService;

    /**
     * 新增
     * @param qrCode
     * @return
     */
    @PostMapping
    public AjaxResult add(@RequestBody QrCode qrCode){
        if (UserConstants.NOT_UNIQUE.equals(qrCodeService.checkNameUnique(qrCode)))
        {
            return AjaxResult.error("新增二维码信息'" + qrCode.getName() + "'失败，二维码信息已存在");
        }
        try {
            String codeName = String.format("%s-%s.jpg", qrCode.getName(), System.currentTimeMillis() + "");
            String destPath = String.format("%s%s", GlobalUtils.getTempBaseDir(),codeName);
            //生成二维码
            QRCodeUtil.encode("内容暂定", null, destPath, true);
            qrCode.setQrPath(destPath);
            qrCode.setCreateBy(SecurityUtils.getUsername());
        }catch (Exception e){
            throw new CustomException("生成二维码图片失败");
        }
        return toAjax(qrCodeService.save(qrCode));

    }

    /**
     * 修改
     */
    @PutMapping
    public AjaxResult edit(@RequestBody QrCode qrCode)
    {
        if (UserConstants.NOT_UNIQUE.equals(qrCodeService.checkNameUnique(qrCode)))
        {
            return AjaxResult.error("修改二维码信息'" + qrCode.getName() + "'失败，二维码信息已存在");
        }
        qrCode.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(qrCodeService.updateById(qrCode));
    }

    @GetMapping("/list")
    public TableDataInfo list(@RequestBody QrCode qrCode)
    {
        startPage();
        List<QrCode> list = qrCodeService.list(qrCode);
        return getDataTable(list);
    }

    /**
     * 删除
     */
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable("id") Long id)
    {
        return toAjax(qrCodeService.remove(id));
    }
}

